cli_option_output_directory_help = """\b
The name of the output directory where the ReST file will be generated.
Kindly make sure that the given directory is not existing already."""
cli_option_theme_help = """\b
The name of the sphinx theme.You can check for the available themes at:
<https://www.sphinx-doc.org/en/master/usage/theming.html#builtin-themes>"""
cli_option_serve_help = """\b
Build HTML using Sphinx and Serve the files on localhost.
Sphinx has to be installed for this to work.
"""
cli_option_build_help = """\b
Build HTML from the generated ReST files using Sphinx.
Sphinx has to be installed for this to work.
"""
cli_option_css_help = """\b
Include the custom CSS and Fonts from the EPUB for the HTML output
"""
cli_option_overwrite_help = """\b
Overwrite the output directory if present already
"""
cli_option_port_help = """\b
The port number on which the files will be served after conversion
"""